env = ARGV[2]
cloud = ARGV[3]
puts "Environment is: #{env}"
search("environment","name:#{env}")do |n|
  prev_version = n.cookbook_versions["webslave"]
  prev_version = n.cookbook_versions["#{cloud}_webslave"] if cloud != "aws"
  a=Time.now.utc
  n.override_attributes.clear
  n.override_attributes[a.to_s]=prev_version
  n.save
end

exit 0

